onDragUpdate property

void Function(DragUpdateDetails) onDragUpdate
final

The callback for drag updates, which should be applied to the draggable part of the dialog (usually the header).

Implementation

final void Function(DragUpdateDetails) onDragUpdate;