DraggableDialogThemeData class

A theme to customize the appearance of the DraggableDialog.

Annotations

Constructors

DraggableDialogThemeData({Color? headerColor, Color? contentColor, Color? footerColor, TextStyle? titleStyle, Color? buttonColor, ButtonStyle? buttonStyle, TextStyle? buttonTextStyle, double? headerHeight, double? footerHeight, double? buttonHeight, double? buttonMinWidth, double? buttonTextSize, double? headerTextSize, double? closeIconSize, Color? closeIconColor})
const
DraggableDialogThemeData.from(BuildContext context)
Creates a default theme for the dialog based on the current ThemeData.
factory

Properties

buttonColor Color?
final
buttonHeight double?
final
buttonMinWidth double?
final
buttonStyle ButtonStyle?
final
buttonTextSize double?
final
buttonTextStyle TextStyle?
final
closeIconColor Color?
final
closeIconSize double?
final
contentColor Color?
final
footerColor Color?
final
footerHeight double?
final
hashCode int
The hash code for this object.
no setterinherited
headerColor Color?
final
headerHeight double?
final
headerTextSize double?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
titleStyle TextStyle?
final

Methods

copyWith({Color? headerColor, Color? contentColor, Color? footerColor, TextStyle? titleStyle, Color? buttonColor, ButtonStyle? buttonStyle, TextStyle? buttonTextStyle, double? headerHeight, double? footerHeight, double? buttonHeight, double? buttonMinWidth, double? buttonTextSize, double? headerTextSize, double? closeIconSize, Color? closeIconColor}) DraggableDialogThemeData
Creates a copy of this theme with the given fields replaced by the new values.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited